@@ -23,7 +23,7 @@ my $milter = new Sendmail::PMilter;
 $milter->auto_setconn($miltername);
 $milter->register($miltername, \%cbs, SMFI_CURR_ACTS);
 
-my $dispatcher = Sendmail::PMilter::ithread_dispatcher(
+my $dispatcher = Sendmail::PMilter::prefork_dispatcher(
 	max_children => 10,
 	max_requests_per_child => 100,
 );
